package com.ruoyi.system.mapper.project;

import com.ruoyi.system.domain.project.BmConstructionRate;

import java.util.List;

/**
 * 项目施工进度Mapper接口
 * 
 * @author ruoyi
 * @date 2021-03-08
 */
public interface BmConstructionRateMapper 
{
    /**
     * 查询项目施工进度
     * 
     * @param id 项目施工进度ID
     * @return 项目施工进度
     */
    public BmConstructionRate selectBmConstructionRateById(Long id);

    /**
     * 查询项目施工进度列表
     * 
     * @param bmConstructionRate 项目施工进度
     * @return 项目施工进度集合
     */
    public List<BmConstructionRate> selectBmConstructionRateList(BmConstructionRate bmConstructionRate);

    /**
     * 新增项目施工进度
     * 
     * @param bmConstructionRate 项目施工进度
     * @return 结果
     */
    public int insertBmConstructionRate(BmConstructionRate bmConstructionRate);

    /**
     * 修改项目施工进度
     * 
     * @param bmConstructionRate 项目施工进度
     * @return 结果
     */
    public int updateBmConstructionRate(BmConstructionRate bmConstructionRate);

    /**
     * 删除项目施工进度
     * 
     * @param id 项目施工进度ID
     * @return 结果
     */
    public int deleteBmConstructionRateById(Long id);

    /**
     * 批量删除项目施工进度
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBmConstructionRateByIds(Long[] ids);
}
